@@ -1,5 +1,6 @@
 import os
 import telebot
+from rest_framework.renderers import JSONRenderer
 
 
 class TgLogsMiddleware:
@@ -14,8 +15,11 @@ class TgLogsMiddleware:
         if 400 >= response.status_code <= 500:
             self.bot.send_message(
                 chat_id=os.getenv('chat_id'),
-                text=f'Status code: {response.status_code}\nBody: {response.body}',
+                text=f'Status code: {response.status_code}',
                 disable_web_page_preview=True
             )
+        # response.accepted_renderer = JSONRenderer()
+        # response.accepted_media_type = "application/json"
+        # response.renderer_context = {}
 
         return response
\ No newline at end of file
